function  MBKS_zobraz_odchylky_nezavaznych_poziadavok(fpls, fmns, gpls, gmns)
% Funkcia, ktora sluzi na zostavenie grafu, ktory zobrazuje odchylky
% pracovnych dni od optimalneho poctu pracovnych dni. 
%
% Volanie
%    MBKS_zostav_zobrazenie6(fpls, fmns, gpls, gmns)
% Vstup:
%   fpls - vektor pre zobrazenie riesenia s nezavaznymi poziadavkami pre kladne odchylky
%   fmns - vektor pre zobrazenie riesenia s nezavaznymi poziadavkami pre zaportne odchylky
%   gpls - vektor pre zobrazenie riesenia s nezavaznymi poziadavkami pre kladne odchylky
%   gmns - vektor pre zobrazenie riesenia s nezavaznymi poziadavkami pre zaporne odchylky
% Výstup:
%   Graf odchyliek pracovnych dni od optimalneho poctu pracovnych dni
%   Graf celkovej odchylky rozdielu dennych od nocnych smien
%% ABOUT
% Pridanim nezavaznych poziadavkov pribudli neznáme f+, f-, g+, g-, kde
% kazda z nich predstavuje vektor o velkosti n. Tieto nezname vstupuju do
% funkcie pre zobrazenie odchyliek pracovnych dni od optimalneho poctu
% pracovnych dni. Neznamu pre prve nezavazne obmedzenie f ziskame odcitanim
% fmns od fpls, naopak neznamu pre druhe nezavazne obmedzenie g ziskame
% odcitanim gpls od gmns. Takto ziskane vektory potom vykreslujeme pomocou
% funkcie bar. 

%% Deklaracia a populacia vektorov nezavazncy poziadavkov
f = fmns - fpls;
g = gpls - gmns;

%% Vykreslenie odchylky od optimalneho poctu pracovnych dni
subplot(211);
bar(f,'stacked')
hold off;
grid off;
title(['Odchylka od optimálneho počtu pracovných dní l'],'FontSize',16);
xlabel('Sestra','fontsize',12);
ylabel('Odchylka','fontsize',12);

%% Vykreslenie celkovej odchylky rozdielu dennych od nocnych smien
subplot(212);
bar(g,'stacked')
hold off;
grid off;
title(['Celková odchylka rozdielu denných od nočných smien'],'FontSize',16);
xlabel('Sestra','fontsize',12);
ylabel('Odchylka','fontsize',12);

end